@@ -8,7 +8,7 @@ use Try::Tiny;
 use DBIx::Class::Schema::Loader::Utils qw/sigwarn_silencer/;
 use namespace::clean;
 
-our $VERSION = '0.07037';
+our $VERSION = '0.07038';
 
 =head1 NAME
 
@@ -185,7 +185,7 @@ EOF
     $sth->execute($table->name, $table->schema);
 
     while (my ($trigger_body) = $sth->fetchrow_array) {
-        if (my ($seq_schema, $seq_name) = $trigger_body =~ /(?:\."?(\w+)"?)?"?(\w+)"?\.nextval/i) {
+        if (my ($seq_schema, $seq_name) = $trigger_body =~ /(?:"?(\w+)"?\.)?"?(\w+)"?\.nextval/i) {
             if (my ($col_name) = $trigger_body =~ /:new\.(\w+)/i) {
                 $col_name = $self->_lc($col_name);
 
@@ -199,6 +199,9 @@ EOF
         }
     }
 
+    # Old DBD::Oracle report the size in (UTF-16) bytes, not characters
+    my $nchar_size_factor = $DBD::Oracle::VERSION >= 1.52 ? 1 : 2;
+
     while (my ($col, $info) = each %$result) {
         no warnings 'uninitialized';
 
@@ -229,7 +232,7 @@ EOF
                 $info->{size} = $info->{size}[0] / 8;
             }
             else {
-                $info->{size} = $info->{size} / 2;
+                $info->{size} = $info->{size} / $nchar_size_factor;
             }
         }
         elsif ($info->{data_type} =~ /^(?:var)?char2?\z/i) {
